{% include "common/header.j2" %}

/**
 * @ingroup     boards_{{ board.name }}
 * @{
 *
 * @file
 * @brief       Configuration of CPU peripherals for {{ board.displayed_name }} board
 *
 * @author      {{ global.author_name }} <{{ global.author_email }}>
 */

#ifndef PERIPH_CONF_H
#define PERIPH_CONF_H

#include <stdint.h>

#include "cpu.h"
#include "periph_cpu.h"

#ifdef __cplusplus
extern "C" {
#endif

/* put here the board peripherals definitions:
- Available clocks
- Timers
- UARTs
- PWMs
- SPIs
- I2C
- ADC
- RTC
- RTT
etc
 */

#ifdef __cplusplus
}
#endif

#endif /* PERIPH_CONF_H */
/** @} */
