/**
 * @defgroup pkg_{{ pkg.name }}   {{ pkg.displayed_name }}
 * @ingroup  pkg
 * @brief    {{ pkg.description }}
 *
 * # Introduction
 *
 * Put an introduction of the package here 
 *
 * # License
 * 
 * Licensed under {{ pkg.license }}.
 *
 * @see      {{ pkg.url }}
 */
