{% include "common/header.j2" %}

/**
{% if application.type is defined %}
{% if application.type == "example" %}
 * @ingroup     examples
{% endif %}
{% if application.type == "test" %}
 * @ingroup     tests
{% endif %}
{% endif %}
 * @{
 *
 * @file
 * @brief       {{ application.brief }}
 *
 * @author      {{ global.author_name }} <{{ global.author_email }}>
 *
 * @}
 */

#include <stdio.h>

int main(void)
{
    puts("Generated RIOT application: '{{ application.name }}'");
    return 0;
}
