/*
{% if global.license == "MIT" %}
 * MIT License
 *
{% endif %}
{% if global.license != "Apache2" %}
 * Copyright (C) {{ global.year }} {{ global.organization }}
 *
{% endif %}
{{ global.license_header }}
 */
