{% include "common/header.j2" %}

/**
 * @ingroup     boards_{{ board.name }}
 * @{
 *
 * @file
 * @brief       Board specific implementations for the {{ board.displayed_name }} board
 *
 * @author      {{ global.author_name }} <{{ global.author_email }}>
 *
 * @}
 */

#include "cpu.h"
#include "board.h"
#include "periph/gpio.h"

void board_init(void)
{
    /* initialize the CPU */
    cpu_init();
}
