{% include "common/header.j2" %}

/**
 * @ingroup     drivers_{{ driver.name }}
 * @{
 *
 * @file
 * @brief       Internal addresses, registers and constants
 *
 * @author      {{ global.author_name }} <{{ global.author_email }}>
 */

#ifndef {{ driver.name|upper }}_CONSTANTS_H
#define {{ driver.name|upper }}_CONSTANTS_H

#ifdef __cplusplus
extern "C" {
#endif

/* define here the addresses, register and constants of the driver */

#ifdef __cplusplus
}
#endif

#endif /* {{ driver.name|upper }}_CONSTANTS_H */
/** @} */
