/**
 * @defgroup    boards_{{ board.name }} {{ board.displayed_name }}
 * @ingroup     boards
 * @brief       Support for the {{ board.displayed_name }} board.
 *
 * ### General information
 *
 * Some general information about the board
 *
 * ### Pinout
 *
 * A detailed description of the board pinout (if available)
 *
 * ### Flash the board
 *
 * Some notes about how to flash the board
 *
 */
