{% include "common/header.j2" %}

/**
 * @defgroup    sys_{{ module.name }} {{ module.displayed_name }}
 * @ingroup     sys
 * @brief       {{ module.brief }}
 *
 * @{
 *
 * @file
 *
 * @author      {{ global.author_name }} <{{ global.author_email }}>
 */

#ifndef {{ module.name|upper }}_H
#define {{ module.name|upper }}_H

/* Add header includes here */

#ifdef __cplusplus
extern "C" {
#endif

/* Declare the API of the module */

#ifdef __cplusplus
}
#endif

#endif /* {{ module.name|upper }}_H */
/** @} */
