{% include "common/header.j2" %}

/**
 * @ingroup     module_{{ module.name }}
 * @{
 *
 * @file
 * @brief       {{ module.displayed_name }} implementation
 *
 * @author      {{ global.author_name }} <{{ global.author_email }}>
 *
 * @}
 */

#include "{{ module.name }}.h"

/* Implementation of the module */
