{% include "common/header.j2" %}

/**
 * @ingroup     drivers_{{ driver.name }}
 * @{
 *
 * @file
 * @brief       Device driver implementation for the {{ driver.displayed_name }}
 *
 * @author      {{ global.author_name }} <{{ global.author_email }}>
 *
 * @}
 */

#include "{{ driver.name }}.h"
#include "{{ driver.name }}_constants.h"
#include "{{ driver.name }}_params.h"

int {{ driver.name }}_init({{ driver.name }}_t *dev, const {{ driver.name }}_params_t *params)
{

}
